@@ -3,14 +3,13 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.0.2"
+__version__ = "2.0.3"
 __all__ = ['Model', 'Wizard']
 from types import NoneType
 import threading
 import datetime
 from decimal import Decimal
 import proteus.config
-from proteus.pyson import PYSONDecoder
 
 _MODELS = threading.local()
 
@@ -162,7 +161,8 @@ class Many2OneDescriptor(FieldDescriptor):
             value = relation(value)
         elif not value:
             value = None
-        instance._values[self.name] = value
+        if self.name in instance._values:
+            instance._values[self.name] = value
         return value
 
     def __set__(self, instance, value):
@@ -556,7 +556,7 @@ class Model(object):
         'Save the record'
         context = self._config.context
         if self.id < 0:
-            values = self._get_values(fields=self._changed)
+            values = self._get_values()
             self.__id = self._proxy.create(values, context)
         else:
             if not self._changed:
@@ -706,6 +706,8 @@ class Model(object):
 
     def _on_change(self, name):
         'Call on_change for field'
+        # Import locally to not break installation
+        from proteus.pyson import PYSONDecoder
         definition = self._fields[name]
         if definition.get('on_change'):
             if isinstance(definition['on_change'], basestring):
